# ltchiptool-terminal

Simple serial (UART) terminal plugin for [ltchiptool](https://docs.libretiny.eu/docs/flashing/tools/ltchiptool/).

The terminal will automatically connect and disconnect, when the flashing operation ends and starts, respectively.
